<?php
/**
 * Moral Theme Customizer
 *
 * @package Moral
 *
 * service section
 */

$wp_customize->add_section(
	'lawman_pro_main_service',
	array(
		'title' => esc_html__( 'Main Service', 'lawman-pro' ),
		'panel' => 'lawman_pro_home_panel',
	)
);

// service enable settings
$wp_customize->add_setting(
	'lawman_pro_main_service',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_select',
		'default' => 'cat'
	)
);

$wp_customize->add_control(
	'lawman_pro_main_service',
	array(
		'section'		=> 'lawman_pro_main_service',
		'label'			=> esc_html__( 'Content type:', 'lawman-pro' ),
		'description'			=> esc_html__( 'Choose where you want to render the content from.', 'lawman-pro' ),
		'type'			=> 'select',
		'choices'		=> array( 
				'disable' => esc_html__( '--Disable--', 'lawman-pro' ),
				'post' => esc_html__( 'Post', 'lawman-pro' ),
				'page' => esc_html__( 'Page', 'lawman-pro' ),
				'cat' => esc_html__( 'Category', 'lawman-pro' ),
		 	)
	)
);

$wp_customize->add_setting(
	'lawman_pro_main_service_num',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_number_range',
		'default' => 3,
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'lawman_pro_main_service_num',
	array(
		'section'		=> 'lawman_pro_main_service',
		'label'			=> esc_html__( 'Number of Posts:', 'lawman-pro' ),
		'description'			=> esc_html__( 'Min: 3 | Max: 9', 'lawman-pro' ),
		'type'			=> 'number',
		'input_attrs'	=> array( 'min' => 3, 'max' => 9 ),
	)
);


$service_num = get_theme_mod( 'lawman_pro_main_service_num', 3 );
for ($i=1; $i <= $service_num ; $i++) { 

	$wp_customize->add_setting(
		'lawman_pro_main_service_title_'.$i,
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html__( 'Book An', 'lawman-pro' ),
			'transport'	=> 'refresh',
		)
	);
	
	$wp_customize->add_control(
		'lawman_pro_main_service_title_'.$i,
		array(
			'section'		=> 'lawman_pro_main_service',
			'label'			=> esc_html__( 'Title:', 'lawman-pro' ) .$i,
		)
	);

	$wp_customize->add_setting(
		'lawman_pro_main_service_icons_' . $i,
		array(	
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> 'newspaper',
		)
	);

	$wp_customize->add_control(
		'lawman_pro_main_service_icons_' . $i,
		array(
		'label'       => __('Icon ', 'lawman-pro'). $i,
		'description' => sprintf( __('Please input icon as eg: newspaper. Find Font-awesome icons %1$shere%2$s', 'lawman-pro'), '<a href="' . esc_url( 'https://fontawesome.com/cheatsheet/' ) . '" target="_blank">', '</a>' ),
		'section'     => 'lawman_pro_main_service',   	
		'type'        => 'text',
		)
	);
	// service post setting
	$wp_customize->add_setting(
		'lawman_pro_main_service_post_'.$i,
		array(
			'sanitize_callback' => 'lawman_pro_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'lawman_pro_main_service_post_'.$i,
		array(
			'section'		=> 'lawman_pro_main_service',
			'label'			=> esc_html__( 'Post ', 'lawman-pro' ).$i,
			'active_callback' => 'lawman_pro_if_main_service_post',
			'type'			=> 'select',
			'choices'		=> lawman_pro_get_post_choices(),
		)
	);

	// service page setting
	$wp_customize->add_setting(
		'lawman_pro_main_service_page_'.$i,
		array(
			'sanitize_callback' => 'lawman_pro_sanitize_dropdown_pages',
			'default' => 0,
		)
	);

	$wp_customize->add_control(
		'lawman_pro_main_service_page_'.$i,
		array(
			'section'		=> 'lawman_pro_main_service',
			'label'			=> esc_html__( 'Page ', 'lawman-pro' ).$i,
			'type'			=> 'dropdown-pages',
			'active_callback' => 'lawman_pro_if_main_service_page'
		)
	);
}

// service category setting
$wp_customize->add_setting(
	'lawman_pro_main_service_cat',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_select',
	)
);

$wp_customize->add_control(
	'lawman_pro_main_service_cat',
	array(
		'section'		=> 'lawman_pro_main_service',
		'label'			=> esc_html__( 'Category:', 'lawman-pro' ),
		'active_callback' => 'lawman_pro_if_main_service_cat',
		'type'			=> 'select',
		'choices'		=> lawman_pro_get_post_cat_choices(),
	)
);

$wp_customize->add_setting(	
	'lawman_pro_main_service_section_bg_color',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_hex_color',
		'default'			=> '#253042',
	)
);


$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'lawman_pro_main_service_section_bg_color',
		array(
			'section'		=> 'lawman_pro_main_service',
			'label'			=> esc_html__( 'Section Background Color', 'lawman-pro' ),

		)
	)
);

