<?php
/**
 * Moral Theme Customizer
 *
 * @package Moral
 *
 * service section
 */

$wp_customize->add_section(
	'lawman_pro_service',
	array(
		'title' => esc_html__( 'Service', 'lawman-pro' ),
		'panel' => 'lawman_pro_home_panel',
	)
);


// service enable settings
$wp_customize->add_setting(
	'lawman_pro_service',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_select',
		'default' => 'cat'
	)
);

$wp_customize->add_control(
	'lawman_pro_service',
	array(
		'section'		=> 'lawman_pro_service',
		'label'			=> esc_html__( 'Content type:', 'lawman-pro' ),
		'description'	=> esc_html__( 'Choose where you want to render the content from.', 'lawman-pro' ),
		'type'			=> 'select',
		'choices'		=> array( 
				'disable' => esc_html__( '--Disable--', 'lawman-pro' ),
				'post' => esc_html__( 'Post', 'lawman-pro' ),
				'page' => esc_html__( 'Page', 'lawman-pro' ),
				'cat' => esc_html__( 'Category', 'lawman-pro' ),
		 	)
	)
);

$wp_customize->add_setting(
	'lawman_pro_service_exerpt',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_number_range',
		'default' => 30,
		'transport'	=> 'refresh',
	)
);

$wp_customize->add_control(
	'lawman_pro_service_exerpt',
	array(
		'section'		=> 'lawman_pro_service',
		'label'			=> esc_html__( 'Exerpt Length', 'lawman-pro' ),
	)
);


$wp_customize->add_setting(
	'lawman_pro_service_num',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_number_range',
		'default' => 4,
		'transport'	=> 'refresh',
	)
);

$wp_customize->add_control(
	'lawman_pro_service_num',
	array(
		'section'		=> 'lawman_pro_service',
		'label'			=> esc_html__( 'Number of Posts:', 'lawman-pro' ),
		'description'			=> esc_html__( 'Min: 3 | Max: 9', 'lawman-pro' ),
		'type'			=> 'number',
		'input_attrs'	=> array( 'min' => 2, 'max' => 9 ),
	)
);


// service enable settings
$wp_customize->add_setting(
	'lawman_pro_service_column',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_select',
		'default' => 'col-2'
	)
);

$wp_customize->add_control(
	'lawman_pro_service_column',
	array(
		'section'		=> 'lawman_pro_service',
		'label'			=> esc_html__( 'Column Layout:', 'lawman-pro' ),
		'type'			=> 'select',
		'choices'		=> array( 
				'col-2' => esc_html__( 'Two Column', 'lawman-pro' ),
				'col-3' => esc_html__( 'Three Column', 'lawman-pro' ),
				'col-4' => esc_html__( 'Four Column', 'lawman-pro' ),
		 	)
	)
);
$wp_customize->add_setting(
	'lawman_pro_service_title',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => esc_html__( 'We Are Here To Help You Grow', 'lawman-pro' ),
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'lawman_pro_service_title',
	array(
		'section'		=> 'lawman_pro_service',
		'label'			=> esc_html__( 'Title:', 'lawman-pro' ),
	)
);

$wp_customize->selective_refresh->add_partial( 
	'lawman_pro_service_title', 
	array(
        'selector'            => '#our-services .section-title',
		'render_callback'     => 'lawman_pro_service_partial_title',
	) 
);

$wp_customize->add_setting(
	'lawman_pro_service_sub_title',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => esc_html__( 'Our Services', 'lawman-pro' ),
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'lawman_pro_service_sub_title',
	array(
		'section'		=> 'lawman_pro_service',
		'label'			=> esc_html__( 'Sub Title:', 'lawman-pro' ),
	)
);

$wp_customize->selective_refresh->add_partial( 
	'lawman_pro_service_sub_title', 
	array(
        'selector'            => '#our-services .section-subtitle',
		'render_callback'     => 'lawman_pro_service_partial_sub_title',
	) 
);

$wp_customize->add_setting(
	'lawman_pro_service_btn_label',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => esc_html__( 'Read More', 'lawman-pro' ),
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'lawman_pro_service_btn_label',
	array(
		'section'		=> 'lawman_pro_service',
		'label'			=> esc_html__( 'Btn label:', 'lawman-pro' ),
	)
);

$wp_customize->selective_refresh->add_partial( 
	'lawman_pro_service_btn_label', 
	array(
        'selector'            => '#service .section-btn_label',
		'render_callback'     => 'lawman_pro_service_partial_btn_label',
	) 
);


$service_num = get_theme_mod( 'lawman_pro_service_num', 4 );
for ($i=1; $i <= $service_num ; $i++) { 

	$wp_customize->add_setting(
		'lawman_pro_service_icons_' . $i,
		array(	
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> 'newspaper',
		)
	);

	$wp_customize->add_control(
		'lawman_pro_service_icons_' . $i,
		array(
		'label'       => __('Icon ', 'lawman-pro'). $i,
		'description' => sprintf( __('Please input icon as eg: newspaper. Find Font-awesome icons %1$shere%2$s', 'lawman-pro'), '<a href="' . esc_url( 'https://fontawesome.com/cheatsheet/' ) . '" target="_blank">', '</a>' ),
		'section'     => 'lawman_pro_service',   	
		'type'        => 'text',
		)
	);
	// service post setting
	$wp_customize->add_setting(
		'lawman_pro_service_post_'.$i,
		array(
			'sanitize_callback' => 'lawman_pro_sanitize_dropdown_pages',
		)
	);

	$wp_customize->add_control(
		'lawman_pro_service_post_'.$i,
		array(
			'section'		=> 'lawman_pro_service',
			'label'			=> esc_html__( 'Post ', 'lawman-pro' ).$i,
			'active_callback' => 'lawman_pro_if_service_post',
			'type'			=> 'select',
			'choices'		=> lawman_pro_get_post_choices(),
		)
	);

	// service page setting
	$wp_customize->add_setting(
		'lawman_pro_service_page_'.$i,
		array(
			'sanitize_callback' => 'lawman_pro_sanitize_dropdown_pages',
			'default' => 0,
		)
	);

	$wp_customize->add_control(
		'lawman_pro_service_page_'.$i,
		array(
			'section'		=> 'lawman_pro_service',
			'label'			=> esc_html__( 'Page ', 'lawman-pro' ).$i,
			'type'			=> 'dropdown-pages',
			'active_callback' => 'lawman_pro_if_service_page'
		)
	);
}

// service category setting
$wp_customize->add_setting(
	'lawman_pro_service_cat',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_select',
	)
);

$wp_customize->add_control(
	'lawman_pro_service_cat',
	array(
		'section'		=> 'lawman_pro_service',
		'label'			=> esc_html__( 'Category:', 'lawman-pro' ),
		'active_callback' => 'lawman_pro_if_service_cat',
		'type'			=> 'select',
		'choices'		=> lawman_pro_get_post_cat_choices(),
	)
);

$wp_customize->add_setting( 'lawman_pro_service_image', array(
	'sanitize_callback' => 'lawman_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'lawman_pro_service_image',
		array(
		'label'       		=> esc_html__( 'Image', 'lawman-pro' ),
		'description' 		=> esc_html__( 'Recommended Image with no background ', 'lawman-pro' ),
		'section'     		=> 'lawman_pro_service',
) ) );

$wp_customize->add_setting(
	'lawman_pro_service_btn_title',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => esc_html__( 'View all Services', 'lawman-pro' ),
		'transport'	=> 'postMessage',
	)
);

$wp_customize->add_control(
	'lawman_pro_service_btn_title',
	array(
		'section'			=> 'lawman_pro_service',
		'label'				=> esc_html__( 'Btn Title:', 'lawman-pro' ),
		'active_callback'	=> function(){
			return get_theme_mod( 'lawman_pro_homepage_layout' ) == 'second-design';
		}
		
	)
);

$wp_customize->selective_refresh->add_partial( 
	'lawman_pro_service_btn_title', 
	array(
		'selector'            => '#service .read-more a',
		'render_callback'     => 'lawman_pro_service_partial_btn_title',
	) 
);



$wp_customize->add_setting(
	'lawman_pro_service_btn_url',
	array(
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	'lawman_pro_service_btn_url',
	array(
		'section'		=> 'lawman_pro_service',
		'label'			=> esc_html__( 'Btn Url:', 'lawman-pro' ),
		'active_callback'	=> function(){
			return get_theme_mod( 'lawman_pro_homepage_layout' ) == 'second-design';
		}
	)
);


// service enable background settings
$wp_customize->add_setting(
	'lawman_pro_service_background',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_select',
		'default'			=> 'image',
	)
);

$wp_customize->add_control(
	'lawman_pro_service_background',
	array(
		'label'			=> esc_html__( 'Enable Background', 'lawman-pro' ),
		'section'		=> 'lawman_pro_service',
		'type'			=> 'radio',
		'choices'		=> array( 
				'image' => esc_html__( 'Background Image', 'lawman-pro' ),
				'color' => esc_html__( 'Background Color', 'lawman-pro' ),
		 	),
	)
);

$wp_customize->add_setting( 'lawman_pro_service_background_image', array(
	'sanitize_callback' => 'lawman_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'lawman_pro_service_background_image',
	array(
	'label'       		=> esc_html__( 'Upload Image', 'lawman-pro' ),
	'section'     		=> 'lawman_pro_service',
	'active_callback'	=> 'lawman_pro_if_service_background_image',
) ) );

$wp_customize->add_setting(	
	'lawman_pro_service_background_color',
	array(
		'sanitize_callback' => 'lawman_pro_sanitize_hex_color',
	)
);

$wp_customize->add_control(
	new WP_Customize_Color_Control( 
	$wp_customize,
		'lawman_pro_service_background_color',
		array(
			'section'		=> 'lawman_pro_service',
			'label'			=> esc_html__( 'Select BG Color:', 'lawman-pro' ),
			'active_callback' => 'lawman_pro_if_service_background_color',
		)
	)
);